@@ -274,11 +274,7 @@ killswitch_state_changed (BluetoothKillswitch *killswitch, KillswitchState state
 	gboolean bstate = FALSE;
 	const char *label, *status_label;
 
-	if (state == KILLSWITCH_STATE_UNKNOWN || state == KILLSWITCH_STATE_MIXED) {
-		sensitive = FALSE;
-		label = NULL;
-		status_label = N_("Bluetooth: Unknown");
-	} else if (state == KILLSWITCH_STATE_SOFT_BLOCKED) {
+	if (state == KILLSWITCH_STATE_SOFT_BLOCKED) {
 		label = N_("Turn On Bluetooth");
 		status_label = N_("Bluetooth: Off");
 		bstate = FALSE;
@@ -286,6 +282,10 @@ killswitch_state_changed (BluetoothKillswitch *killswitch, KillswitchState state
 		label = N_("Turn Off Bluetooth");
 		status_label = N_("Bluetooth: On");
 		bstate = TRUE;
+	} else if (state == KILLSWITCH_STATE_HARD_BLOCKED) {
+		sensitive = FALSE;
+		label = NULL;
+		status_label = N_("Bluetooth: Disabled");
 	} else {
 		g_assert_not_reached ();
 	}
@@ -309,10 +309,23 @@ killswitch_state_changed (BluetoothKillswitch *killswitch, KillswitchState state
 static GtkWidget *create_popupmenu(void)
 {
 	GObject *object;
+	GError *error = NULL;
 
 	xml = gtk_builder_new ();
-	if (gtk_builder_add_from_file (xml, "popup-menu.ui", NULL) == 0)
-		gtk_builder_add_from_file (xml, PKGDATADIR "/popup-menu.ui", NULL);
+	if (gtk_builder_add_from_file (xml, "popup-menu.ui", &error) == 0) {
+		if (error->domain == GTK_BUILDER_ERROR) {
+			g_warning ("Failed to load popup-menu.ui: %s", error->message);
+			g_error_free (error);
+			return NULL;
+		}
+		g_error_free (error);
+		error = NULL;
+		if (gtk_builder_add_from_file (xml, PKGDATADIR "/popup-menu.ui", &error) == 0) {
+			g_warning ("Failed to load popup-menu.ui: %s", error->message);
+			g_error_free (error);
+			return NULL;
+		}
+	}
 
 	gtk_builder_connect_signals (xml, NULL);
 
@@ -350,21 +363,19 @@ update_menu_items (void)
 	if (num_adapters_present == 0)
 		enabled = FALSE;
 	else
-		enabled = (num_adapters_present - num_adapters_powered) >= 0;
+		enabled = (num_adapters_present - num_adapters_powered) <= 0;
 
+	object = gtk_builder_get_object (xml, "adapter-action-group");
+	gtk_action_group_set_visible (GTK_ACTION_GROUP (object), enabled);
+	gtk_action_group_set_visible (devices_action_group, enabled);
 
-	object = gtk_builder_get_object (xml, "send-file");
-	gtk_action_set_sensitive (GTK_ACTION (object),
-				  enabled &&
-				  (program_available ("obex-data-server")
-				   || program_available ("obexd")));
+	if (enabled == FALSE)
+		return;
 
 	object = gtk_builder_get_object (xml, "browse-device");
 	gtk_action_set_sensitive (GTK_ACTION (object),
-				  enabled && program_available ("nautilus"));
+				  program_available ("nautilus"));
 
-	object = gtk_builder_get_object (xml, "setup-new");
-	gtk_action_set_sensitive (GTK_ACTION (object), enabled);
 }
 
 static void
@@ -996,6 +1007,10 @@ int main(int argc, char *argv[])
 			  G_CALLBACK (device_changed), NULL);
 	/* Set the default */
 	device_changed (devices_model, NULL, NULL, NULL);
+	if (killswitch != NULL) {
+		killswitch_state_changed (killswitch,
+					  bluetooth_killswitch_get_state (killswitch));
+	}
 
 	gconf = gconf_client_get_default();
 
