@@ -32,8 +32,10 @@
 #include <dbus/dbus-glib.h>
 
 #include <bluetooth-client.h>
+#include <bluetooth-client-private.h>
 #include <bluetooth-killswitch.h>
 #include <bluetooth-chooser.h>
+#include <bluetooth-plugin-manager.h>
 
 #include "adapter.h"
 #include "general.h"
@@ -167,29 +169,24 @@ static void wizard_callback(GtkWidget *button, gpointer user_data)
 		g_printerr("Couldn't execute command: %s\n", command);
 }
 
-static gboolean show_confirm_dialog(void)
+static gboolean show_confirm_dialog(const char *name)
 {
 	GtkWidget *dialog;
 	gint response;
-	gchar *text;
 
-	text = g_strdup_printf("<big><b>%s</b></big>\n\n%s",
-				_("Remove from list of known devices?"),
-				_("If you delete the device, you have to "
-					"set it up again before next use."));
-	dialog = gtk_message_dialog_new_with_markup(NULL, GTK_DIALOG_MODAL,
-				GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, NULL);
-	gtk_message_dialog_set_markup(GTK_MESSAGE_DIALOG(dialog), text);
-	g_free(text);
+	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
+					 _("Remove '%s' from the list of devices?"), name);
+	g_object_set (G_OBJECT (dialog), "secondary-text",
+		      _("If you remove the device, you will have to set it up again before next use."),
+		      NULL);
 
-	gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL,
-							GTK_RESPONSE_CANCEL);
-	gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_DELETE,
-							GTK_RESPONSE_ACCEPT);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_REMOVE, GTK_RESPONSE_ACCEPT);
 
-	response = gtk_dialog_run(GTK_DIALOG(dialog));
+	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
-	gtk_widget_destroy(dialog);
+	gtk_widget_destroy (dialog);
 
 	if (response == GTK_RESPONSE_ACCEPT)
 		return TRUE;
@@ -197,17 +194,26 @@ static gboolean show_confirm_dialog(void)
 	return FALSE;
 }
 
-static void delete_callback(GtkWidget *button, gpointer user_data)
+static void remove_callback(GtkWidget *button, gpointer user_data)
 {
 	adapter_data *adapter = user_data;
 	GValue value = { 0, };
 	DBusGProxy *device;
 	const char *path;
+	char *address, *name;
 
 	if (bluetooth_chooser_get_selected_device_info (BLUETOOTH_CHOOSER (adapter->chooser),
 							"proxy", &value) == FALSE) {
 		return;
 	}
+	address = bluetooth_chooser_get_selected_device (BLUETOOTH_CHOOSER (adapter->chooser));
+	name = bluetooth_chooser_get_selected_device_name (BLUETOOTH_CHOOSER (adapter->chooser));
+	if (address == NULL || name == NULL) {
+		g_value_unset (&value);
+		g_free (address);
+		g_free (name);
+		return;
+	}
 	device = g_value_dup_object (&value);
 	g_value_unset (&value);
 
@@ -216,12 +222,21 @@ static void delete_callback(GtkWidget *button, gpointer user_data)
 
 	path = dbus_g_proxy_get_path(device);
 
-	if (show_confirm_dialog() == TRUE) {
-		dbus_g_proxy_call(adapter->proxy, "RemoveDevice", NULL,
-					DBUS_TYPE_G_OBJECT_PATH, path,
-					G_TYPE_INVALID, G_TYPE_INVALID);
+	if (show_confirm_dialog (name) == TRUE) {
+		GError *err = NULL;
+		if (dbus_g_proxy_call (adapter->proxy, "RemoveDevice", &err,
+				       DBUS_TYPE_G_OBJECT_PATH, path,
+				       G_TYPE_INVALID, G_TYPE_INVALID) == FALSE) {
+			g_warning ("Failed to remove device %s: %s", address,
+				   err->message);
+			g_error_free (err);
+		} else {
+			bluetooth_plugin_manager_device_deleted (address);
+		}
 	}
 
+	g_free (address);
+	g_free (name);
 	g_object_unref(device);
 }
 
@@ -334,7 +349,7 @@ static void create_adapter(adapter_data *adapter)
 	gtk_box_pack_start(GTK_BOX(mainbox), vbox, FALSE, TRUE, 0);
 
 	/* The discoverable checkbox */
-	button = gtk_check_button_new_with_mnemonic (_("_Discoverable"));
+	button = gtk_check_button_new_with_mnemonic (_("Make computer _discoverable"));
 	if (powered == FALSE)
 		discoverable = FALSE;
 	if (discoverable != FALSE && timeout == 0)
@@ -387,7 +402,7 @@ static void create_adapter(adapter_data *adapter)
 	table = gtk_table_new(2, 2, FALSE);
 	gtk_box_pack_start(GTK_BOX(mainbox), table, TRUE, TRUE, 0);
 
-	label = create_label(_("Known devices"));
+	label = create_label(_("Devices"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 2, 0, 1,
 			 GTK_EXPAND | GTK_FILL, GTK_SHRINK, 0, 6);
 
@@ -395,7 +410,7 @@ static void create_adapter(adapter_data *adapter)
 	 * adapter, this is on purpose */
 	adapter->chooser = bluetooth_chooser_new (NULL);
 	g_object_set (adapter->chooser,
-		      "show-search", FALSE,
+		      "show-searching", FALSE,
 		      "show-device-type", FALSE,
 		      "show-device-category", FALSE,
 		      "show-pairing", TRUE,
@@ -419,7 +434,7 @@ static void create_adapter(adapter_data *adapter)
 	gtk_table_attach(GTK_TABLE(table), buttonbox, 1, 2, 1, 2,
 			 GTK_FILL, GTK_FILL, 6, 6);
 
-	button = gtk_button_new_with_label(_("Setup new device..."));
+	button = gtk_button_new_with_mnemonic(_("Set up _new device..."));
 	image = gtk_image_new_from_stock(GTK_STOCK_ADD,
 						GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image(GTK_BUTTON(button), image);
@@ -442,8 +457,8 @@ static void create_adapter(adapter_data *adapter)
 
 	adapter->button_disconnect = button;
 
-	button = gtk_button_new_with_label(_("Delete"));
-	image = gtk_image_new_from_stock(GTK_STOCK_DELETE,
+	button = gtk_button_new_with_mnemonic(_("_Remove"));
+	image = gtk_image_new_from_stock(GTK_STOCK_REMOVE,
 						GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image(GTK_BUTTON(button), image);
 	gtk_box_pack_end(GTK_BOX(buttonbox), button, FALSE, FALSE, 0);
@@ -452,7 +467,7 @@ static void create_adapter(adapter_data *adapter)
 	gtk_widget_set_sensitive(button, FALSE);
 
 	g_signal_connect(G_OBJECT(button), "clicked",
-				G_CALLBACK(delete_callback), adapter);
+				G_CALLBACK(remove_callback), adapter);
 
 	adapter->button_delete = button;
 
